@@ -14,6 +14,7 @@ import re
 
 from requests_mock import adapter
 from . import base
+from requests_mock.response import _MatcherResponse
 
 ANY = adapter.ANY
 
@@ -140,7 +141,6 @@ class TestMatcher(base.TestCase):
                              'http://www.test.com/abc')
         self.assertMatchBoth('http://www.test.com:5000/abc',
                              'http://www.test.com:5000/abc')
-
         self.assertNoMatchBoth('https://www.test.com',
                                'http://www.test.com')
         self.assertNoMatchBoth('http://www.test.com/abc',
@@ -158,6 +158,14 @@ class TestMatcher(base.TestCase):
         self.assertNoMatchBoth('http://test.com/abc/',
                                'http://www.test.com:5000/abc')
 
+    def test_quotation(self):
+        self.assertMatchBoth('http://www.test.com/a string%url',
+                             'http://www.test.com/a string%url')
+        self.assertMatchBoth('http://www.test.com/ABC 123',
+                             'http://www.test.com/ABC%20123')
+        self.assertMatchBoth('http://www.test.com/user@example.com',
+                             'http://www.test.com/user@example.com')
+
     def test_subset_match(self):
         self.assertMatch('/path', 'http://www.test.com/path')
         self.assertMatch('/path', 'http://www.test.com/path')
@@ -294,3 +302,23 @@ class TestMatcher(base.TestCase):
                            matcher_method='POST',
                            request_data='goodbye world',
                            additional_matcher=test_match_body)
+
+    def test_reset_reverts_count(self):
+        url = 'mock://test/site/'
+        matcher = adapter._Matcher('GET',
+                                   url,
+                                   [_MatcherResponse()],
+                                   complete_qs=False,
+                                   additional_matcher=None,
+                                   request_headers={},
+                                   real_http=False,
+                                   case_sensitive=False)
+        request = adapter._RequestObjectProxy._create('GET', url)
+
+        call_count = 3
+        for _ in range(call_count):
+            matcher(request)
+
+        self.assertEqual(matcher.call_count, call_count)
+        matcher.reset()
+        self.assertEqual(matcher.call_count, 0)
